@@ -9,12 +9,9 @@
 #'   (Kmult: Adams 2014). This value evaluates the degree of phylogenetic signal
 #'   in a dataset relative to what is expected under a Brownian motion model of evolution. For geometric
 #'   morphometric data, the approach is a mathematical generalization of the Kappa statistic (Blomberg et al. 
-#'   2003) appropriate for highly multivariate data (see Adams 2014).Significance testing 
-#'   is found by permuting the shape data among the tips of the phylogeny. In addition, a multivariate 
-#'   effect size describing the strength of the effect is 
-#'   estimated from the empirically-generated sampling distribution (see details in Adams and Collyer 2019).
-#'   Values from these distributions are log-transformed prior to effect size estimation, 
-#'   to assure normally distributed data. 
+#'   2003) appropriate for highly multivariate data (see Adams 2014). Significance testing 
+#'   is found by permuting the shape data among the tips of the phylogeny. And effect size can be estimated
+#'   based on likelihood method that finds and optimal scaling of the tree; see  \code{\link{physignal.z}}.
 #' 
 #' This function can also be used with univariate data (i.e. centroid size) if imported as matrix with rownames
 #' giving the taxa names. In this case, the estimate of phylogenetic signal is identical to that found using the 
@@ -23,6 +20,11 @@
 #'  The generic functions, \code{\link{print}}, \code{\link{summary}}, and \code{\link{plot}} all work with \code{\link{physignal}}.
 #'  The generic function, \code{\link{plot}}, produces a histogram of random K statistics, associated with the resampling procedure.
 #'  
+#'  \subsection{Notes for geomorph 4.0}{ 
+#' Starting with version 4.0.2, this function no longer reports an effect size.  Effect sizes for phylogenetic signal
+#' can be calculated with physignal.z, based on likelihood.
+#' }
+#'  
 #'  \subsection{Notes for geomorph 3.0}{ 
 #' Compared to older versions of geomorph, the order of input variables has changed, so that it is consistent with other functions
 #' in the program. Additionally, users should note that the function physignal no longer contains
@@ -40,12 +42,11 @@
 #' This is helpful for long-running analyses.
 #' @keywords analysis
 #' @author Dean Adams and Michael Collyer
-#' @seealso \code{\link{gm.prcomp}}
+#' @seealso \code{\link{gm.prcomp}}, \code{\link{physignal.z}}
 #' @export
 #' @return Function returns a list with the following components: 
 #'   \item{phy.signal}{The estimate of phylogenetic signal.}
 #'   \item{pvalue}{The significance level of the observed signal.}
-#'   \item{Effect.Size}{The multivariate effect size associated with sigma.d.ratio.}
 #'   \item{random.K}{Each random K-statistic from random permutations.}
 #'   \item{permutations}{The number of random permutations used in the resampling procedure.}
 #'   \item{PACA}{A phylogenetically aligned component analysis, based on OLS residuals.}
@@ -148,7 +149,6 @@ physignal <- function(A, phy, iter = 999, seed = NULL, print.progress = FALSE){
   if(print.progress) close(pb)
 
   p.val <- pval(K.rand)
-  Z <- effect.size(K.rand, center=TRUE) 
   
   # Kmult by paca
   x <- as.matrix(x)
@@ -169,7 +169,7 @@ physignal <- function(A, phy, iter = 999, seed = NULL, print.progress = FALSE){
     PaCA <- P <- K.by.p <- NULL
   }
   
-  out <- list(phy.signal = K.rand[[1]], pvalue = p.val, random.K = K.rand, Z = Z,
+  out <- list(phy.signal = K.rand[[1]], pvalue = p.val, random.K = K.rand, 
               permutations = iter+1, 
               PACA = PaCA, K.by.p = K.by.p, call=match.call())
   
